import 'package:flutter/material.dart';
import 'package:flutter_inappwebview/flutter_inappwebview.dart';

class WebviewContainer extends StatelessWidget {
  WebviewContainer({Key? key, required this.url}) : super(key: key);

  final String url;
  final GlobalKey webViewKey = GlobalKey();

  InAppWebViewController? webViewController;
  InAppWebViewSettings settings =
      InAppWebViewSettings(javaScriptEnabled: true, geolocationEnabled: true);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Webview Example'),
      ),
      body: SizedBox(
        width: double.infinity,
        // the most important part of this example
        child: InAppWebView(
          key: webViewKey,
          // initialUrlRequest: URLRequest(url: WebUri('https://flutter.dev')),
          onWebViewCreated: (InAppWebViewController controller) async {
            await controller.loadUrl(urlRequest: URLRequest(url: WebUri(url)));
            controller.addJavaScriptHandler(
              handlerName: 'PayDala',
              callback: (args) {
                // print arguments coming from the JavaScript side!
                print('Received arguments from JavaScript: ');
                print(args);

                // return data to the JavaScript side!
              },
            );
            if (await WebViewFeature.isFeatureSupported(
                WebViewFeature.WEB_MESSAGE_LISTENER)) {
              await controller.addWebMessageListener(WebMessageListener(
                jsObjectName: "PayDala",
                allowedOriginRules: {"*"},
                onPostMessage:
                    (message, sourceOrigin, isMainFrame, replyProxy) {
                  print("Received message from $sourceOrigin: $message");
                },
              ));
            }
          },
          onLoadStart: (InAppWebViewController controller, Uri? url) {
            print('onLoadStart $url');
          },
          onLoadStop: (InAppWebViewController controller, Uri? url) {
            print('onLoadStop $url');
          },
          onProgressChanged: (InAppWebViewController controller, int progress) {
            print('onProgressChanged $progress');
          },
          onGeolocationPermissionsShowPrompt:
              (InAppWebViewController controller, String origin) async {
            return GeolocationPermissionShowPromptResponse(
                origin: origin, allow: true, retain: true);
          },
        ),
      ),
    );
  }
}
